/**
 * The main entrypoint when using Bun as the runtime
 */

import { IRuntime, RunTimeType } from '../common/runtime.ts';
import TerminalIO from '../tsx/terminal_io.ts';
import FileIO from '../tsx/file_io.ts';

import process from 'node:process';

/**
 * The Bun Runtime implementation
 */
const BunRuntime: IRuntime = {
	name: RunTimeType.Bun,
	file: FileIO,
	term: TerminalIO,
	onEvent: (eventName: string, handler) => process.on(eventName, handler),
	onExit: (cb: () => void): void => {
		process.on('beforeExit', cb);
		process.on('exit', cb);
		process.on('SIGINT', cb);
	},
	exit: (code?: number) => process.exit(code),
};

export default BunRuntime;
